==> humhub-1.11.0-beta.2.tar.gz: humhub-1.11.0-beta.2/protected/humhub/messages/ja/base.php <==
<?php

return [
    '<strong>Confirm</strong> Action' => '<strong>確認</strong> アクション',
    '<strong>Latest</strong> updates' => '<strong>最新</strong>情報',
    '<strong>Mail</strong> summary' => '<strong>メール</strong>サマリー',
    'Account settings' => 'アカウント設定',
    'Actions' => 'アクション',
    'Add:' => '追加：',
    'Administration' => '管理',
    'All' => 'すべて',
    'Allow' => '許可',
    'An error occurred while handling your last action. (Handler not found).' => '処理中にエラーが発生しました。 （ハンドラが見つかりません。）',
    'An unexpected error occurred while loading the search result.' => '検索結果の読み込み中に予期しないエラーが発生しました。',
    'An unexpected error occurred. If this keeps happening, please contact a site administrator.' => '予期しないエラーが発生しました。サイト管理者に連絡してください。',
    'An unexpected server error occurred. If this keeps happening, please contact a site administrator.' => '予期しないサーバーエラーが発生しました。 サイト管理者に連絡してください。',
    'An unknown error occurred while uploading.' => 'アップロード中に不明なエラーが発生しました。',
    'An unknown error occurred while uploading. Hint: check your upload_max_filesize and post_max_size php settings.' => 'アップロード中に不明なエラーが発生しました。 PHPの設定を確認してください。',
    'Back' => '戻る',
    'Back to dashboard' => 'ダッシュボードへ戻る',
    'Cancel' => 'キャンセル',
    'Choose language:' => '言語を選択：',
    'Close' => '閉じる',
    'Collapse' => '折りたたむ',
    'Confirm' => '確認',
    'Content Addon source must be instance of HActiveRecordContent or HActiveRecordContentAddon!' => 'コンテンツアドオンソースは HActiveRecordContent または HActiveRecordContentAddon のインスタンスでなければなりません！',
    'Copy to clipboard' => 'クリップボードにコピー',
    'Could not find content of addon!' => 'アドオンのコンテンツを見つけることができませんでした！',
    'Could not find requested page.' => '要求されたページが見つかりませんでした。',
    'Default' => 'デフォルト',
    'Delete' => '削除',
    'Deny' => '拒否',
    'Do you really want to perform this action?' => '本当に実行しますか？',
    'Edit' => '編集',
    'Error' => 'エラー',
    'Error while running your last action (Invalid request method).' => '実行中にエラーが発生しました（無効なリクエストメソッド）',
    'Error:' => 'エラー：',
    'Expand' => '拡大',
    'Export' => 'エクスポート',
    'Info:' => '情報：',
    'Invalid request method!' => '無効なリクエストです！',
    'It looks like you may have taken the wrong turn.' => '間違った順になっている可能性があります。',
    'Language' => '言語',
    'Loading...' => '読み込み中...',
    'Login' => 'ログイン',
    'Logo of {appName}' => '{appName} のロゴ',
    'Logout' => 'ログアウト',
    'Menu' => 'メニュー',
    'Module is not enabled on this content container!' => 'このコンテンツコンテナに有効なモジュールがありません。',
    'My profile' => 'マイプロフィール',
    'New profile image' => '新しいプロフィール画像',
    'Next' => '次',
    'No error information given.' => 'エラー情報はありません。',
    'Oooops...' => 'おっと・・・',
    'Open' => '開く',
    'Please type at least 3 characters' => '3文字以上入力してください。',
    'Please type at least {count} characters' => '少なくとも {count} 文字が必要です。',
    'Powered by {name}' => 'Powered by {name}',
    'Profile dropdown' => 'ドロップダウンプロフィール',
    'Profile picture of {displayName}' => '{displayName} さんのプロフィール写真',
    'Save' => '保存',
    'Saved' => '保存しました',
    'Search' => '検索',
    'Select Me' => '自分を選ぶ',
    'Show less' => '少なく表示',
    'Show more' => 'もっと見る',
    'Some files could not be uploaded:' => '一部のファイルをアップロードできませんでした：',
    'Stop impersonation' => 'なりすましを止める',
    'Text could not be copied to clipboard' => 'テキストをクリップボードにコピーできませんでした。',
    'Text has been copied to clipboard' => 'テキストがクリップボードにコピーされました。',
    'The date has to be in the past.' => '日付は過去である必要があります。',
    'The file has been deleted.' => 'ファイルを削除しました。',
    'The requested resource could not be found.' => '要求されたリソースが見つかりませんでした。',
    'The space has been archived.' => 'スペースをアーカイブしました。',
    'The space has been unarchived.' => 'スペースをアーカイブから復元しました。',
    'Time Zone' => 'タイムゾーン',
    'Toggle comment menu' => 'コメントメニューの切り替え',
    'Toggle panel menu' => 'パネルメニューの切り替え',
    'Toggle post menu' => 'ポストメニューの切り替え',
    'Toggle stream entry menu' => 'ストリーム入力メニューの切り替え',
    'Unsaved changes will be lost. Do you want to proceed?' => '保存されていない変更があります。このページから移動しますか？',
    'Unsubscribe' => '退会',
    'Upload' => 'アップロード',
    'Upload file' => 'ファイルをアップロード',
    'You are not allowed to run this action.' => 'この操作を実行することはできません。',
    '{nFormatted}B' => '{nFormatted}B',
    '{nFormatted}K' => '{nFormatted}K',
    '{nFormatted}M' => '{nFormatted}M',
    'Allow content from external source' => '',
    'Always allow content from this provider!' => '',
    'Do you want to enable content from \'{urlPrefix}\'?' => '',
];

==> humhub-1.15.0-beta.2.tar.gz: humhub-1.15.0-beta.2/protected/humhub/messages/ja/base.php <==
<?php

return [
    '<strong>Confirm</strong> Action' => '<strong>確認</strong> アクション',
    '<strong>Latest</strong> updates' => '<strong>最新</strong>情報',
    '<strong>Mail</strong> summary' => '<strong>メール</strong>サマリー',
    'Actions' => 'アクション',
    'Add:' => '追加：',
    'Administration' => '管理',
    'All' => 'すべて',
    'Allow' => '許可',
    'Allow content from external source' => '外部ソースからのコンテンツを許可する',
    'Always allow content from this provider!' => 'このプロバイダからのコンテンツを常に許可してください',
    'An error occurred while handling your last action. (Handler not found).' => '処理中にエラーが発生しました。 （ハンドラが見つかりません。）',
    'An unexpected error occurred while loading the search result.' => '検索結果の読み込み中に予期しないエラーが発生しました。',
    'An unexpected error occurred. If this keeps happening, please contact a site administrator.' => '予期しないエラーが発生しました。サイト管理者に連絡してください。',
    'An unexpected error occurred. Please check whether your file exceeds the allowed upload limit of {maxUploadSize}.' => '予期しないエラーが発生しました。ファイルが許可されているアップロード制限 {maxUploadSize} を超えていないか確認してください。',
    'An unexpected server error occurred. If this keeps happening, please contact a site administrator.' => '予期しないサーバーエラーが発生しました。 サイト管理者に連絡してください。',
    'Back' => '戻る',
    'Back to dashboard' => 'ダッシュボードへ戻る',
    'Cancel' => 'キャンセル',
    'Choose language:' => '言語を選択：',
    'Close' => '閉じる',
    'Collapse' => '折りたたむ',
    'Confirm' => '確認',
    'Content Addon source must be instance of HActiveRecordContent or HActiveRecordContentAddon!' => 'コンテンツアドオンソースは HActiveRecordContent または HActiveRecordContentAddon のインスタンスでなければなりません！',
    'Copy to clipboard' => 'クリップボードにコピー',
    'Could not find content of addon!' => 'アドオンのコンテンツを見つけることができませんでした！',
    'Could not find requested page.' => '要求されたページが見つかりませんでした。',
    'Default' => 'デフォルト',
    'Delete' => '削除',
    'Deny' => '拒否',
    'Do you really want to perform this action?' => '本当に実行しますか？',
    'Do you want to enable content from \'{urlPrefix}\'?' => '’{urlPrefix}’のコンテンツを有効にしますか？',
    'Edit' => '編集',
    'Error' => 'エラー',
    'Error while running your last action (Invalid request method).' => '実行中にエラーが発生しました（無効なリクエストメソッド）',
    'Error:' => 'エラー：',
    'Expand' => '拡大',
    'Export' => 'エクスポート',
    'Info:' => '情報：',
    'Invalid request method!' => '無効なリクエストです！',
    'It looks like you may have taken the wrong turn.' => '道を間違ったかもしれません。',
    'Language' => '言語',
    'Loading...' => '読み込み中...',
    'Login' => 'ログイン',
    'Logo of {appName}' => '{appName} のロゴ',
    'Logout' => 'ログアウト',
    'Menu' => 'メニュー',
    'Module is not enabled on this content container!' => 'このコンテンツコンテナに有効なモジュールがありません。',
    'My Profile' => 'マイプロフィール',
    'New profile image' => '新しいプロフィール画像',
    'Next' => '次',
    'No error information given.' => 'エラー情報はありません。',
    'Oooops...' => 'おっと・・・',
    'Open' => '開く',
    'Please type at least 3 characters' => '3文字以上入力してください。',
    'Please type at least {count} characters' => '少なくとも {count} 文字が必要です。',
    'Powered by {name}' => 'Powered by {name}',
    'Profile dropdown' => 'ドロップダウンプロフィール',
    'Profile picture of {displayName}' => '{displayName} さんのプロフィール写真',
    'Save' => '保存',
    'Saved' => '保存しました',
    'Search' => '検索',
    'Search...' => '探す...',
    'Select Me' => '自分を選ぶ',
    'Settings' => '設定',
    'Show less' => '少なく表示',
    'Show more' => 'もっと見る',
    'Some files could not be uploaded:' => '一部のファイルをアップロードできませんでした：',
    'Stop impersonation' => 'なりすましを止める',
    'Text could not be copied to clipboard' => 'テキストをクリップボードにコピーできませんでした。',
    'Text has been copied to clipboard' => 'テキストがクリップボードにコピーされました。',
    'The date has to be in the past.' => '日付は過去である必要があります。',
    'The file has been deleted.' => 'ファイルを削除しました。',
    'The requested resource could not be found.' => '要求されたリソースが見つかりませんでした。',
    'The space has been archived.' => 'スペースをアーカイブしました。',
    'The space has been unarchived.' => 'スペースをアーカイブから復元しました。',
    'Time Zone' => 'タイムゾーン',
    'Toggle comment menu' => 'コメントメニューの切り替え',
    'Toggle panel menu' => 'パネルメニューの切り替え',
    'Toggle post menu' => 'ポストメニューの切り替え',
    'Toggle stream entry menu' => 'ストリーム入力メニューの切り替え',
    'Unsaved changes will be lost. Do you want to proceed?' => '保存されていない変更があります。このページから移動しますか？',
    'Unsubscribe' => '退会',
    'Upload' => 'アップロード',
    'Upload file' => 'ファイルをアップロード',
    'You are not allowed to run this action.' => 'この操作を実行することはできません。',
    'verify your upload_max_filesize and post_max_size php settings.' => 'Upload_max_filesize と post_max_size の php 設定を確認してください。',
    '{nFormatted}B' => '{nFormatted}B',
    '{nFormatted}K' => '{nFormatted}K',
    '{nFormatted}M' => '{nFormatted}M',
    '{attribute} has been empty. The system-configured function to fill empty values has returned an invalid value. Please try again or contact your administrator.' => '',
    '{attribute} must be a string (UUID) or null; {type} given.' => '',
    '{attribute} must be an UUID or null. UUID has the format "{{XXXXXXXX-XXXX-XXXX-XXXX-XXXXXXXXXXXX}}", where X = [a-fA-F0-9] and both curly brackets and delimiting dashes are optional.' => '',
];
